@@ -17,7 +17,7 @@
 //! - `std`: Enable some trait impl for types that only exist on the `std` and the Error
 //! trait
 //! - `unicode`: Enable more methods for JanetString and JanetBuffer
-//! - `inline-more`: More agressive inlining
+//! - `inline-more`: More aggressive inlining
 //! - `amalgation`: Link the Janet runtime to the package, enabling to use the client
 //!   module
 //! - `unicode`: Enable some unicode methods for JanetString and JanetBuffer
@@ -56,7 +56,7 @@
 //!  - Marshalling mechanism
 #![cfg_attr(not(feature = "std"), no_std)]
 #![cfg_attr(feature = "nightly", feature(allocator_api))]
-#![cfg_attr(feature = "_doc", feature(doc_cfg))]
+#![cfg_attr(_doc, feature(doc_cfg))]
 
 // Cause compilation error when both almagation and system is set
 #[cfg(all(feature = "amalgation", feature = "link-system"))]
