@@ -33,7 +33,7 @@ impl fmt::Display for AbstractError {
 }
 
 #[cfg(feature = "std")]
-#[cfg_attr(feature = "_doc", doc(cfg(feature = "std")))]
+#[cfg_attr(_doc, doc(cfg(feature = "std")))]
 impl std::error::Error for AbstractError {}
 
 /// Type that represents the Janet Abstract type.
